@@ -111,9 +111,6 @@ FAT2DBC.ad=function(f1,
   fator1a=fator1
   fator2a=fator2
   block=as.factor(block)
-  # ================================
-  # Transformacao de dados
-  # ================================
   if(transf==1){resp=response+constant}else{resp=((response+constant)^transf-1)/transf}
   if(transf==0){resp=log(response+constant)}
   if(transf==0.5){resp=sqrt(response+constant)}
@@ -185,7 +182,7 @@ FAT2DBC.ad=function(f1,
     statistic=homog1$`F value`[1]
     phomog=homog1$`Pr(>F)`[1]
     method="Levene's Test (center = median)(F)"
-    names(homog1)=c("Df", "F value","p.value")}
+    names(homog1)=c("Df", "statistic","p.value")}
 
   indep = dwtest(b)
   resids=b$residuals/sqrt(an$`Mean Sq`[5])
@@ -265,11 +262,6 @@ FAT2DBC.ad=function(f1,
     message("\nYour analysis is not valid, suggests using the function FATDIC.art\n")}else{}
   message(if(transf !=1){blue("NOTE: resp = transformed means; respO = averages without transforming\n")})
 
-
-  #------------------------------------
-  # Fatores isolados
-  #------------------------------------
-
   if (anava$`Pr(>F)`[4] > alpha.f)
   { cat(green(bold("-----------------------------------------------------------------\n")))
     cat(green(bold("No significant interaction")))
@@ -283,7 +275,6 @@ FAT2DBC.ad=function(f1,
       cat(bold(fac.names[i]))
       cat(green(bold("\n-----------------------------------------------------------------\n")))
       if(quali[i]==TRUE){
-        ## Tukey
         if(mcomp=="tukey"){
           letra <- TUKEY(resp, fatores[,i], anava$Df[6],
                             anava$`Mean Sq`[6], alpha=alpha.t)
@@ -302,8 +293,6 @@ FAT2DBC.ad=function(f1,
                         QME = anava$`Mean Sq`[5],
                         alpha = alpha.t)
           letra1=data.frame(resp=medias,groups=sk)
-          # letra=sk(resp, fatores[,i], anava$Df[6],anava$`Sum Sq`[6],alpha.t)
-          # letra1 <- letra; colnames(letra1)=c("resp","groups")
           if(transf !=1){letra1$respo=tapply(response,fatores[,i],mean, na.rm=TRUE)[rownames(letra1)]}}
         if(mcomp=="duncan"){
           letra <- duncan(resp, fatores[,i],anava$Df[6],anava$`Mean Sq`[6], alpha=alpha.t)
@@ -352,9 +341,6 @@ FAT2DBC.ad=function(f1,
                 axis.text = element_text(size=textsize,color="black",family=family),
                 axis.title = element_text(size=textsize,color="black",family=family))}
 
-        # ================================
-        # grafico de pontos
-        # ================================
         if(geom=="point"){grafico=ggplot(dadosm,
                                          aes(x=trats,
                                              y=media))
@@ -380,7 +366,7 @@ FAT2DBC.ad=function(f1,
                 axis.text = element_text(size=textsize,color="black",family=family),
                 axis.title = element_text(size=textsize,color="black",family=family))}
         grafico=grafico+
-          geom_hline(aes(color=ad.label,group=ad.label,yintercept=mean(responseAd,na.rm=T)),lty=2)+
+          geom_hline(aes(color=ad.label,group=ad.label,yintercept=mean(responseAd,na.rm=TRUE)),lty=2)+
           scale_color_manual(values = "black")+labs(color="")
         if(CV==TRUE){grafico=grafico+labs(caption=paste("p-value = ", if(anava$`Pr(>F)`[i]<0.0001){paste("<", 0.0001)}
                                                         else{paste("=", round(anava$`Pr(>F)`[i],4))},"; CV = ",
@@ -390,9 +376,7 @@ FAT2DBC.ad=function(f1,
         cat("\n\n")
       }
 
-      # Regression
       if(quali[i]==FALSE){
-        # dose=as.numeric(as.character(as.vector(unlist(fatores[i]))))
         dose=as.vector(unlist(fatoresa[i]))
         grafico=polynomial(dose,
                            response,
@@ -407,8 +391,6 @@ FAT2DBC.ad=function(f1,
                            family=family)
         grafico=grafico[[1]]}
 
-      # Ns
-      #if (a$`Pr(>F)`[i] > alpha.f) {cat("\nAccording to the F test, the means do not differ\n")}
       graficos[[i+1]]=grafico}}
     graficos[[1]]=residplot
     if(anava$`Pr(>F)`[1]>=alpha.f && anava$`Pr(>F)`[2] <alpha.f){
@@ -433,21 +415,11 @@ FAT2DBC.ad=function(f1,
       print(tapply(response,list(fator1,fator2),mean, na.rm=TRUE))}
   }
 
-  #-----------------------------------
-  # Interação
-  #-----------------------------------
-
-  # Desdobramento de F1 dentro de F2
-
   if (anava$`Pr(>F)`[4]  <= alpha.f) {
     fatores <- data.frame(Fator1, Fator2)
     cat(green(bold("-----------------------------------------------------------------\n")))
     cat(green(bold("Significant interaction: analyzing the interaction")))
     cat(green(bold("\n-----------------------------------------------------------------\n")))
-    # cat("\n-----------------------------------------------------------------\n")
-    # cat("Analyzing ", fac.names[1], " inside of each level of ",fac.names[2])
-    # cat("\n-----------------------------------------------------------------\n")
-    # cat("\n")
     des1<-aov(resp~Fator2/Fator1+block)
 
     l1<-vector('list',nv2)
@@ -466,9 +438,6 @@ FAT2DBC.ad=function(f1,
     print(des1.tab)
     desdobramento1=des1.tab
     if(quali[1]==TRUE & quali[2]==TRUE){
-      #-------------------------------------
-      # Teste de comparação
-      #-------------------------------------
       if (mcomp == "tukey"){
         tukeygrafico=c()
         ordem=c()
@@ -547,8 +516,6 @@ FAT2DBC.ad=function(f1,
         letra=datag$letra}
     }
 
-    # Desdobramento de F2 dentro de F1
-
     cat("\n-----------------------------------------------------------------\n")
     cat("Analyzing ", fac.names[2], " inside of the level of ",fac.names[1])
     cat("\n-----------------------------------------------------------------\n")
@@ -571,9 +538,6 @@ FAT2DBC.ad=function(f1,
     print(des1.tab)
     desdobramento2=des1.tab
 
-    #-------------------------------------
-    # Teste de comparação
-    #-------------------------------------
     if(quali[1]==TRUE & quali[2]==TRUE){
       if (mcomp == "tukey"){
         tukeygrafico1=c()
@@ -622,7 +586,6 @@ FAT2DBC.ad=function(f1,
                         QME = anava$`Mean Sq`[6],
                         alpha = alpha.t)
           sk=data.frame(respi=medias,groups=sk)
-          # sk=sk(respi,trati,anava$Df[6],anava$`Sum Sq`[6],alpha.t)
           if(transf !="1"){sk$respo=tapply(respi,trati,mean, na.rm=TRUE)[rownames(sk)]}
           skgrafico1[[i]]=sk[levels(trati),2]
         }
@@ -645,7 +608,7 @@ FAT2DBC.ad=function(f1,
                             family=family,
                             ylim=ylim)}
       if(quali[2]==TRUE){
-        Fator1=fator1a#as.numeric(as.character(Fator1))
+        Fator1=fator1a
         grafico=polynomial2(Fator1,
                             response,
                             Fator2,
@@ -662,7 +625,7 @@ FAT2DBC.ad=function(f1,
     }
     if(quali[1]==FALSE && color=="rainbow"| quali[2]==FALSE && color=="rainbow"){
       if(quali[2]==FALSE){
-        Fator2=fator2a#as.numeric(as.character(Fator2))
+        Fator2=fator2a
         grafico=polynomial2_color(Fator2,
                                   response,
                                   Fator1,
@@ -677,7 +640,7 @@ FAT2DBC.ad=function(f1,
                                   family=family,
                                   ylim=ylim)}
       if(quali[2]==TRUE){
-        Fator1=fator1a#as.numeric(as.character(Fator1))
+        Fator1=fator1a
         grafico=polynomial2_color(Fator1,
                                   response,
                                   Fator2,
@@ -692,9 +655,6 @@ FAT2DBC.ad=function(f1,
                                   family=family,
                                   ylim=ylim)}
     }
-    # -----------------------------
-    # Gráfico de colunas
-    #------------------------------
     if(quali[1] & quali[2]==TRUE){
       media=tapply(response,list(Fator1,Fator2), mean, na.rm=TRUE)
       desvio=tapply(response,list(Fator1,Fator2), sd, na.rm=TRUE)
@@ -750,7 +710,7 @@ FAT2DBC.ad=function(f1,
                           legend.text = element_text(family = family,size = textsize),
                           legend.title = element_text(family = family,size = textsize),
                           legend.position = posi)+labs(fill=legend)+
-        geom_hline(aes(color=ad.label,yintercept=mean(responseAd,na.rm=T)),lty=2)+
+        geom_hline(aes(color=ad.label,yintercept=mean(responseAd,na.rm=TRUE)),lty=2)+
         scale_color_manual(values = "black")+labs(color="")
       if(CV==TRUE){colint=colint+labs(caption=paste("p-value ", if(anava$`Pr(>F)`[4]<0.0001){paste("<", 0.0001)}
                                                     else{paste("=", round(anava$`Pr(>F)`[4],4))},"; CV = ",
