@@ -135,7 +135,7 @@ DQL=function(trat,
     statistic=homog1$`F value`[1]
     phomog=homog1$`Pr(>F)`[1]
     method="Levene's Test (center = median)(F)"
-    names(homog1)=c("Df", "F value","p.value")}
+    names(homog1)=c("Df", "statistic","p.value")}
 
   indep = dwtest(b)
 
